/* $Workfile: OtxHdlcD.h $   $Revision: 46 $    $Modtime: 5/08/08 12:09p $  */
#ifndef OTX_HDLC_DEF_H
#define OTX_HDLC_DEF_H
/*******************************************************************************

  @doc PublicHwApi OtxHdlcD

  Copyright (C) 1998 - 2008 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxHdlcD | Constants, Macros, and Types for the HDLC Logical Device Functions

  @contents2
  OtxHdlcD.h |

  @index enum type struct | OtxHdlcD

  @contents2
  OTX HDLC Logical Device Macros, Constants, and Types |

  @head3 Enumerated Types  |

  @index enum | OtxHdlcD

  @head3 Struct Types |

  @index struct | OtxHdlcD

  @head3 Constants |

  @index const | OtxHdlcD

  @head3 Other Types |

  @index type | OtxHdlcD

*******************************************************************************/

#include "OtxErr.h" 
#include "OtxType.h"

#ifdef __cplusplus
  extern "C" {
#endif

#if defined(__linux__)
#pragma pack(1)
#elif defined(__BORLANDC__)
#pragma option push -a1
#else
#pragma pack(push,1)
#endif

#if 0
#define OD_HDLC_MAX_TX_HDLC_FRAME_LEN    8192
#define OD_HDLC_MAX_RX_HDLC_FRAME_LEN    8192
#else // Temporary reduced. Will be brought back to 8192 in future releases
#define OD_HDLC_MAX_TX_HDLC_FRAME_LEN    2048
#define OD_HDLC_MAX_RX_HDLC_FRAME_LEN    2048
#endif

#define OTX_HDLC_MAX_REPEAT_DATA_LEN    10


// Filter masks in the SS7 mode
// @type OTX_HDLC_SS7_FILTER_FISU | Filters identical consecutive FISU frames (LI=0)
#define OTX_HDLC_SS7_FILTER_FISU             0x01
// @type OTX_HDLC_SS7_FILTER_SHORT_LSSU | Filters identical consecutive short LSSU frames (LI=1)
#define OTX_HDLC_SS7_FILTER_SHORT_LSSU       0x02
// @type OTX_HDLC_SS7_FILTER_LONG_LSSU | Filters identical consecutive long LSSU frames (LI=2)
#define OTX_HDLC_SS7_FILTER_LONG_LSSU        0x04
// @type OTX_HDLC_SS7_FILTER_MSU | Filters all MSU frames (LI>2)
#define OTX_HDLC_SS7_FILTER_MSU              0x08
// @type OTX_HDLC_SS7_FILTER_FISU_ALL | Filters all FISU frames (LI=0)
#define OTX_HDLC_SS7_FILTER_FISU_ALL         0x10
// @type OTX_HDLC_SS7_FILTER_SHORT_LSSU_ALL | Filters all short LSSU frames (LI=1)
#define OTX_HDLC_SS7_FILTER_SHORT_LSSU_ALL   0x20
// @type OTX_HDLC_SS7_FILTER_LONG_LSSU_ALL | Filters all long LSSU frames (LI=2)
#define OTX_HDLC_SS7_FILTER_LONG_LSSU_ALL    0x40


// FISU/LSSU Element Extraction Macros
#define OTX_HDLC_SS7_BSN_MASK              0x0000007F  // Backward Sequence Number
#define OTX_HDLC_SS7_BIB_MASK              0x00000080  // Backward Indicator Bit
#define OTX_HDLC_SS7_FSN_MASK              0x00007F00  // Forward Sequence Number
#define OTX_HDLC_SS7_FIB_MASK              0x00008000  // Forward Indicator Bit
#define OTX_HDLC_SS7_LI_MASK               0x003F0000  // Length Indication
#define OTX_HDLC_SS7_SF_MASK               0x07000000  // Status Field

#define OTX_HDLC_SS7_FISU_EXTRACT_BSN( bsn, buf32)     bsn = (OTX_UINT8) buf32 & OTX_HDLC_SS7_BSN_MASK

#define OTX_HDLC_SS7_FISU_EXTRACT_BIB( bib, buf32)     bib = (OTX_UINT8) ((buf32 & OTX_HDLC_SS7_BIB_MASK) >> 7)

#define OTX_HDLC_SS7_FISU_EXTRACT_FSN( fsn, buf32)     fsn = (OTX_UINT8) ((buf32 & OTX_HDLC_SS7_FSN_MASK) >> 8)

#define OTX_HDLC_SS7_FISU_EXTRACT_FIB( fib, buf32)     fib = (OTX_UINT8) ((buf32 & OTX_HDLC_SS7_FIB_MASK) >> 15)

#define OTX_HDLC_SS7_FISU_EXTRACT_LI( li, buf32)       li =  (OTX_UINT8) ((buf32 & OTX_HDLC_SS7_LI_MASK) >> 16)

// addition for LSSU 
#define OTX_HDLC_SS7_LSSU_EXTRACT_SF( sf, buf32)       sf =  (OTX_UINT8) ((buf32 & OTX_HDLC_SS7_SF_MASK) >> 24)

/******************************************************************************
  @enum 
    HDLC Receiver Attributes
******************************************************************************/
enum OtxHdlcReceiverAttributesE {
  OTX_ATTR_HDLC_RECEIVER_FIFO_SIZE_FRAMES            = OTX_ATTR_END +  0,  // @emem (OTX_ATTRIB_UINT32) Read only. Size of allocated buffer for the HDLC Receiver Fifo (in number of frames)
  OTX_ATTR_HDLC_RECEIVER_FIFO_SIZE_OCTETS            = OTX_ATTR_END +  1,  // @emem (OTX_ATTRIB_UINT32) Read only. Size of allocated buffer for the HDLC Receiver Fifo (in number of bytes)
  OTX_ATTR_HDLC_RECEIVER_FIFO_PEAK_USAGE_OCTETS      = OTX_ATTR_END +  2,  // @emem (OTX_ATTRIB_UINT32) Read only. Peak usage (in octets) of the HDLC Receiver Fifo
  OTX_ATTR_HDLC_RECEIVER_FIFO_PEAK_USAGE_FRAMES      = OTX_ATTR_END +  3,  // @emem (OTX_ATTRIB_UINT32) Read only. Peak usage (in frames) of the HDLC Receiver Fifo
  OTX_ATTR_HDLC_RECEIVER_FIFO_CURRENT_USAGE_OCTETS   = OTX_ATTR_END +  4,  // @emem (OTX_ATTRIB_UINT32) Read only. Current usage (in octets) of the HDLC Receiver Fifo
  OTX_ATTR_HDLC_RECEIVER_FIFO_CURRENT_USAGE_FRAMES   = OTX_ATTR_END +  5,  // @emem (OTX_ATTRIB_UINT32) Read only. Current usage (in frames) of the HDLC Receiver Fifo
  OTX_ATTR_HDLC_RECEIVER_FIFO_LOST_FRAMES            = OTX_ATTR_END +  6,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of lost frames (due to Fifo-full condition)
  OTX_ATTR_HDLC_RECEIVER_USE_FRAME_COUNT_AS_SEQUENCE = OTX_ATTR_END +  7,  // @emem (OTX_ATTRIB_BOOL) Read/Write. Default OTX_FALSE. If set OTX_TRUE the driver 
                                                                           // write the frame counter number (if available) in the pnFrameSeq parameter of the <f OtxHdlcReadData> 
                                                                           // function. For more information about the frame counter, please refer to
                                                                           // the <e OtxDspDeviceAttributesE.OTX_ATTR_DSP_FRAME_BUFFER_COUNTER> attribute.
                                                                           // The frame counter number could be used to accurately timestamp events (such as received
                                                                           // HDLC frames).
  OTX_ATTR_HDLC_RECEIVER_MTP2_FISU_FILTER            = OTX_ATTR_END +  8,  // @emem (OTX_ATTRIB_BOOL) Read/Write. Default OTX_FALSE. 
                                                                           // Support for MTP2 FISU Filter. 
                                                                           // If the MAC layer receives 2 consecutive FISU packet  
                                                                           // with the same data, the 2 FISU are passed to MTP-2
                                                                           // layer. The rest of FISU packets are filtered by the 
                                                                           // MAC (hardware) layer. When the MAC layer receives a  
                                                                           // filter reset, it will again send the next 2 consecutive 
                                                                           // and identcal FISU packet to MTP-2 layer and filter the
                                                                           // other FISU packets. The packet reset is performed when
                                                                           // the attribute is set to OTX_TRUE.
  OTX_ATTR_HDLC_RECEIVER_MTP2_LSSU_FILTER            = OTX_ATTR_END +  9,  // @emem (OTX_ATTRIB_BOOL) Read/Write. Default OTX_FALSE. 
                                                                           // Support for MTP2 LSSU Filter.
                                                                           // If the MAC layer receives 2 consecutive LSSU packet  
                                                                           // with the same data, the 2 LSSU are passed to MTP-2
                                                                           // layer. The rest of LSSU packets are filtered by the 
                                                                           // MAC (hardware) layer. When the MAC layer receives a  
                                                                           // filter reset, it will again send the next 2 consecutive 
                                                                           // and identcal LSSU packet to MTP-2 layer and filter the
                                                                           // other LSSU packets. The packet reset is performed when
                                                                           // the attribute is set to OTX_TRUE.
  OTX_ATTR_HDLC_RECEIVER_SS7_SIGNAL_LSSU_FISU_COUNT  = OTX_ATTR_END +  10, // @emem (OTX_ATTRIB_BOOL) Read/Write. Default OTX_FALSE. 
                                                                           // Support for LSSU/FISU counters.
                                                                           // Count of previous LSSU/FISU when new LSSU/FISU is detected.
                                                                           // The counting events are only generated if set to OTX_TRUE.
                                                                           // The count is reset when the attribute is set to OTX_TRUE.
                                                                           // <e OtxHdlcReceiverEventCodesE.OTX_HDLC_RECEIVER_EC_SS7_FISU_COUNT> event generated.
                                                                           // <e OtxHdlcReceiverEventCodesE.OTX_HDLC_RECEIVER_EC_SS7_LSSU_COUNT> event generated.
  OTX_ATTR_HDLC_RECEIVER_END                         = OTX_ATTR_END + 11
};

typedef enum OtxHdlcReceiverAttributesE OtxHdlcReceiverAttributesE;


/******************************************************************************
  @enum
    HDLC Receiver Event Codes
******************************************************************************/
enum OtxHdlcReceiverEventCodesE {
  OTX_HDLC_RECEIVER_EC_COMPLETE_FRAME      = 0x00, // @emem HDLC Frame Received
  OTX_HDLC_RECEIVER_EC_START_FRAME         = 0x01, // @emem HDLC Receive Frame Start
  OTX_HDLC_RECEIVER_EC_PROTOCOL_ERROR      = 0x02, // @emem HDLC Protocol Error
  OTX_HDLC_RECEIVER_EC_BUFFER_OVERRUN      = 0x03, // @emem HDLC Buffer Overrun. The host is too slow retrieving the data from the Hdlc Receiver
  OTX_HDLC_RECEIVER_EC_SS7_FISU_COUNT      = 0x04, // @emem Count of previous FISU when new FISU comes in.
                                                   // <e OtxHdlcReceiverAttributesE.OTX_ATTR_HDLC_RECEIVER_SS7_SIGNAL_LSSU_FISU_COUNT> generted if set OTX_TRUE.
  OTX_HDLC_RECEIVER_EC_SS7_LSSU_COUNT      = 0x05, // @emem Count of previous LSSU when new LSSU comes in.
                                                   // <e OtxHdlcReceiverAttributesE.OTX_ATTR_HDLC_RECEIVER_SS7_SIGNAL_LSSU_FISU_COUNT> generted if set OTX_TRUE.

  OTX_HDLC_RECEIVER_END_OF_EVENT_CODES
};

typedef enum OtxHdlcReceiverEventCodesE OtxHdlcReceiverEventCodesE;


/******************************************************************************
  @enum
    HDLC Receiver Error Result Codes
******************************************************************************/
enum OtxHdlcReceiverResultCodesE {
  OTX_HDLC_RECEIVER_RES_END = OTX_RES_END + 0
};

typedef enum OtxHdlcReceiverResultCodesE OtxHdlcReceiverResultCodesE;


/******************************************************************************
  @enum 
    HDLC Sender Attributes
******************************************************************************/
enum OtxHdlcSenderAttributesE {
  OTX_ATTR_HDLC_SENDER_GENERATE_FRAME_SENT_EVENT    = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_BOOL) Read/Write. (Default is OTX_FALSE);
                                                                         // If OTX_TRUE the HDLC Sender will generate a 
                                                                         // OTX_HDLC_SENDER_EC_FRAME_SENT event after each 
                                                                         // transmitted frame

  OTX_ATTR_HDLC_SENDER_SS7_AUTO_BSN                 = OTX_ATTR_END + 1,  // @emem (OTX_ATTRIB_BOOL) Read/Write. (Default is OTX_FALSE).
                                                                         // <nl>Note: Future feature. Not implemented yet
                                                                         // <nl>The event is only valid for HDLC Sender devices hosted by a DSP device and 
                                                                         // operating in SS7 mode.
                                                                         // When this attribute is set to OTX_TRUE, the HDLC Sender will assume
                                                                         // that there is a HDLC Receiver operating on the same timeslot as the HDLC Sender.
                                                                         // The HDLC Receiver will analyze the FSN (Forward Sequence Number). If the
                                                                         // FSN is one higher than the previous FSN, then the HDLC Sender will use this
                                                                         // number as the BSN of the outgoing messages. If the FSN is not one higher
                                                                         // than the previous FSN, then the HDLC Sender will toggle the BIB of the outgoing
                                                                         // messages.
                                                                         // The HDLC Receiver will also monitor received LSSU messages. If the LSSU 
                                                                         // indicates that the link is "Out of Service", then the HDLC Sender will set 
                                                                         // BSN=0x7F and BIB=1 of the outgoing messages.

  OTX_ATTR_HDLC_SENDER_END                          = OTX_ATTR_END + 2
};

typedef enum OtxHdlcSenderAttributesE OtxHdlcSenderAttributesE;


/******************************************************************************
  @enum
    HDLC Sender Event Codes
******************************************************************************/
enum OtxHdlcSenderEventCodesE {
  OTX_HDLC_SENDER_EC_FRAME_SENT      = 0x00, // @emem HDLC Frame completely sent
                                             // (<e OtxEventDataS.m_nRequestId> is the <p nTaskRef> as passed in <f OtxHdlcSendData> call). 
                                             // Used with <e OtxHdlcSenderEventCodesE.OTX_HDLC_SENDER_EC_FRAME_COUNT_ZERO> 
                                             // to provide the application with a frame sent timestamp. The frame counter is
                                             // increamented every 125 microSec.
                                             // If generation of this event is desired, it must be activated by setting the
                                             // <e OtxHdlcSenderAttributesE.OTX_ATTR_HDLC_SENDER_GENERATE_DATA_EVENTS> to OTX_TRUE.

  OTX_HDLC_SENDER_EC_BUF_UNDERRUN    = 0x01, // @emem Buffer Underrun. Host is to slow supplying HDLC data to the Hdlc Sender

  OTX_HDLC_SENDER_EC_SHORT_FRAME     = 0x02, // @emem Short frame. Trying to transmit a frame of length=1 byte. Frame ignored.

  OTX_HDLC_SENDER_EC_FRAME_LOST      = 0x03, // @emem Internal device error. Frame is lost. This could occur if
                                             // the host (DSP code) of the device runs out of dynamic memory for the packet
                                             // to be transmitted.

//  OTX_HDLC_SENDER_EC_DEBUG_INFO      = 0x04, // @emem Internal use. For driver debugging.
  OTX_HDLC_SENDER_EC_FRAME_COUNT_ZERO= 0x05, // @emem HDLC Frame completely sent 16 bit counter is zero. Used with 
                                             // <e OtxHdlcSenderEventCodesE.OTX_HDLC_SENDER_EC_FRAME_SENT> to provide the
                                             // application with a frame sent timestamp. The application can use this 
                                             // event to calculate the time between packets. 
                                             // If generation of this event is desired, it must be activated by setting the
                                             // <e OtxHdlcSenderAttributesE.OTX_ATTR_HDLC_SENDER_GENERATE_DATA_EVENTS> to OTX_TRUE.

  OTX_HDLC_SENDER_END_OF_EVENT_CODES
};

typedef enum OtxHdlcSenderEventCodesE OtxHdlcSenderEventCodesE;


/******************************************************************************
  @enum
    HDLC Sender Error Result Codes
******************************************************************************/
enum OtxHdlcSenderResultCodesE {
  OTX_HDLC_SENDER_RES_TX_BUSY                  = OTX_RES_END + 0,  // @emem Transmitter is busy sending a frame.
  OTX_HDLC_SENDER_RES_FRAME_TOO_LONG           = OTX_RES_END + 1,  // @emem Frame too long.

  OTX_HDLC_SENDER_RES_END                      = OTX_RES_END + 2
};

typedef enum OtxHdlcSenderResultCodesE OtxHdlcSenderResultCodesE;


/******************************************************************************
  @enum
    Frame End Code for HDLC frames. Specifies whether the frame is a good or
    faulty frame.
    If the frame is a faulty, then this bit mask provides further indications 
    of the cause of the fault. 
    The frame End Code of frame is retrieved by a call to <f OtxHdlcReadData>. 
    Please note that the Frame End Code is a bit mask value. The Frame End 
    code can have multiple values, e.g. both 
    <e OtxHdlcFrameEndCodeE.OTX_HDLC_FEC_INVALID> and 
    <e OtxHdlcFrameEndCodeE.OTX_HDLC_FEC_ABORTED> can be set.
    
  @xref
    <f OtxHdlcReadData>

******************************************************************************/
enum OtxHdlcFrameEndCodeE {
  OTX_HDLC_FEC_OK         = 0x00,         // @emem The frame is a good HDLC frame. No faults
  OTX_HDLC_FEC_INVALID    = 0x01,         // @emem Invalid frame; Either not a multiple of 8 bits, or a short frame
  OTX_HDLC_FEC_OVERFLOW   = 0x02,         // @emem Receive Data Overflow. The host is not servicing the receive FIFO fast enough.
  OTX_HDLC_FEC_BAD_CRC    = 0x04,         // @emem The frame failed the CRC check
  OTX_HDLC_FEC_ABORTED    = 0x10,         // @emem The received frame was aborted
  OTX_HDLC_FEC_TRUNCATED  = 0x20,         // @emem The received frame was too long for the buffer in the driver
}; 

typedef enum OtxHdlcFrameEndCodeE OtxHdlcFrameEndCodeE;


/******************************************************************************

  @enum 
    Character(s) to be send between HDLC frames

******************************************************************************/
enum OtxHdlcFrameFillTypeE {
  OTX_THOR_FFT_NONE     = 0,  // @emem No frame fill between frames
  OTX_HDLC_FFT_FLAGS    = 1,  // @emem Send HDLC flags (0x7E) between the frames.
  OTX_HDLC_FFT_ALL_ONES = 2   // @emem Send all ones (0xFF) between frames.
};

typedef enum OtxHdlcFrameFillTypeE OtxHdlcFrameFillTypeE;


/******************************************************************************

  @enum 
    Cyclic Redundancy Check (CRC) mode

******************************************************************************/
enum OtxHdlcCrcModeE {
  OTX_HDLC_CRC16    = 0,  // @emem 16-bit Cyclic Redundancy Check
  OTX_HDLC_CRC32    = 1   // @emem 32-bit Cyclic Redundancy Check
};

typedef enum OtxHdlcCrcModeE OtxHdlcCrcModeE;


/******************************************************************************

  @enum 
    HDLC Transmission Rates for V.110 and X.30 modes

******************************************************************************/
enum OtxHdlcTxRateE {
  OTX_HDLC_TR_NA      = 0x04, // @emem Transmission Rate Not Applicaple in this Pipe Mode
  OTX_HDLC_TR_600BPS  = 0x00, // @emem Transmission Rate 600 bit/s
  OTX_HDLC_TR_1200BPS = 0x01, // @emem Transmission Rate 1200 bit/s
  OTX_HDLC_TR_2400BPS = 0x02, // @emem Transmission Rate 2400 bit/s
  OTX_HDLC_TR_4800BPS = 0x03, // @emem Transmission Rate 4800 bit/s
};

typedef enum OtxHdlcTxRateE OtxHdlcTxRateE;


/******************************************************************************
  
  @struct 
    Fill-In Signalling Unit (FISU), used in the <t OTX_HDLC_MODE_SS7> mode

  @xref
    <t OTX_HDLC_SS7_CB_FISU>

******************************************************************************/
struct OtxHdlcSS7FisuS {
  OTX_UINT8 bsn : 7;       // @field Backward Sequence Number
  OTX_UINT8 bib : 1;       // @field Backward Indicator Bit
  OTX_UINT8 fsn : 7;       // @field Forward Sequence Number
  OTX_UINT8 fib : 1;       // @field Forward Indicator Bit
  OTX_UINT8 li  : 6;       // @field Length Indication (2)
  OTX_UINT8 reserved : 2;  // @field Reserved
};

typedef struct OtxHdlcSS7FisuS OtxHdlcSS7FisuS;

// @type OTX_HDLC_SS7_CB_FISU | Size of a SS7 FISU (Fill-In Signalling Unit)
#define OTX_HDLC_SS7_CB_FISU 3

/******************************************************************************
  
  @struct 
    Short Link Status Signalling Unit (Short LSSU), used in the <t OTX_HDLC_MODE_SS7> mode

  @xref
    <t OTX_HDLC_SS7_CB_SHORT_LSSU>

******************************************************************************/
struct OtxHdlcSS7ShortLssuS {
  OTX_UINT8 bsn : 7;       // @field Backward Sequence Number
  OTX_UINT8 bib : 1;       // @field Backward Indicator Bit
  OTX_UINT8 fsn : 7;       // @field Forward Sequence Number
  OTX_UINT8 fib : 1;       // @field Forward Indicator Bit
  OTX_UINT8 li  : 6;       // @field Length Indication (2)
  OTX_UINT8 reserved : 2;  // @field Reserved
  OTX_UINT8 sf;            // @field Status Field
};

typedef struct OtxHdlcSS7ShortLssuS OtxHdlcSS7ShortLssuS;

// @type OTX_HDLC_SS7_CB_SHORT_LSSU | Size of a SS7 Short LSSU (Link Status Signalling Unit)
#define OTX_HDLC_SS7_CB_SHORT_LSSU 4

/******************************************************************************
  
  @struct 
    Long Link Status Signalling Unit (Long LSSU), used in the <t OTX_HDLC_MODE_SS7> mode

  @xref
    <t OTX_HDLC_SS7_CB_LONG_LSSU>

******************************************************************************/
struct OtxHdlcSS7LongLssuS {
  OTX_UINT8 bsn : 7;       // @field Backward Sequence Number
  OTX_UINT8 bib : 1;       // @field Backward Indicator Bit
  OTX_UINT8 fsn : 7;       // @field Forward Sequence Number
  OTX_UINT8 fib : 1;       // @field Forward Indicator Bit
  OTX_UINT8 li  : 6;       // @field Length Indication (2)
  OTX_UINT8 reserved : 2;  // @field Reserved
  OTX_UINT16 sf;           // @field Status Field
};

typedef struct OtxHdlcSS7LongLssuS OtxHdlcSS7LongLssuS;

// @type OTX_HDLC_SS7_CB_LONG_LSSU | Size of a SS7 Long LSSU (Link Status Signalling Unit)
#define OTX_HDLC_SS7_CB_LONG_LSSU 5


/******************************************************************************
  
  @struct 
    HDLC info data structs preceeding HDLC data in buffer returned by 
    <f HdlcReadDataEx>.

    Each frame in the buffer is preceeded with a struct of this type. 

******************************************************************************/
struct OtxHdlcFrameInfoS 
{
  OTX_UINT32    cbOctets;                     // @field Number of octets in the frame (not including this struct)
  OTX_UINT32    nFrameSeq;                    // @field Sequence number of the received HDLC frame (matches the number in the event queue)
  OSA_ENUM_DECL(OtxHdlcFrameEndCodeE)  nFrameEndCode;         // @field Frame Status Code
  OTX_DATETIME  nTimeStamp;                   // @field Timestamp of the last received octet of the frame
  OTX_UINT32    nOffsetNext;                  // @field Offset in bytes to the next OtxHdlcFrameInfoS realtive the start of this one or, 0 if this one is last
  OTX_UINT8     sqData[OTX_VARI_SIZE_FIELD];  // @field HDLC data
};

typedef struct OtxHdlcFrameInfoS OtxHdlcFrameInfoS;


#if defined(__linux__)
#pragma pack()
#elif defined(__BORLANDC__)
#pragma option pop
#else
#pragma pack(pop)
#endif


#ifdef __cplusplus
  } // extern "C"
#endif


/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1998 - 2008


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/

#endif // OTX_HDLC_DEF_H
